==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/template/ZookeeperClusterTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface ZookeeperClusterTemplateFluent<A extends ZookeeperClusterTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildStatefulset instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getStatefulset();
    public ResourceTemplate buildStatefulset();
    public A withStatefulset(ResourceTemplate statefulset);
    public Boolean hasStatefulset();
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> withNewStatefulset();
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> withNewStatefulsetLike(ResourceTemplate item);
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> editStatefulset();
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> editOrNewStatefulset();
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> editOrNewStatefulsetLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public ZookeeperClusterTemplateFluent.PodNested<A> withNewPod();
    public ZookeeperClusterTemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public ZookeeperClusterTemplateFluent.PodNested<A> editPod();
    public ZookeeperClusterTemplateFluent.PodNested<A> editOrNewPod();
    public ZookeeperClusterTemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildClientService instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getClientService();
    public ResourceTemplate buildClientService();
    public A withClientService(ResourceTemplate clientService);
    public Boolean hasClientService();
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> withNewClientService();
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> withNewClientServiceLike(ResourceTemplate item);
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> editClientService();
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> editOrNewClientService();
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> editOrNewClientServiceLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildNodesService instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getNodesService();
    public ResourceTemplate buildNodesService();
    public A withNodesService(ResourceTemplate nodesService);
    public Boolean hasNodesService();
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> withNewNodesService();
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> withNewNodesServiceLike(ResourceTemplate item);
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> editNodesService();
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> editOrNewNodesService();
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> editOrNewNodesServiceLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPersistentVolumeClaim instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getPersistentVolumeClaim();
    public ResourceTemplate buildPersistentVolumeClaim();
    public A withPersistentVolumeClaim(ResourceTemplate persistentVolumeClaim);
    public Boolean hasPersistentVolumeClaim();
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> withNewPersistentVolumeClaim();
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> withNewPersistentVolumeClaimLike(ResourceTemplate item);
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> editPersistentVolumeClaim();
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> editOrNewPersistentVolumeClaim();
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> editOrNewPersistentVolumeClaimLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildZookeeperContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getZookeeperContainer();
    public ContainerTemplate buildZookeeperContainer();
    public A withZookeeperContainer(ContainerTemplate zookeeperContainer);
    public Boolean hasZookeeperContainer();
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> withNewZookeeperContainer();
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> withNewZookeeperContainerLike(ContainerTemplate item);
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> editZookeeperContainer();
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> editOrNewZookeeperContainer();
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> editOrNewZookeeperContainerLike(ContainerTemplate item);
    
/**
 * This method has been deprecated, please use method buildTlsSidecarContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getTlsSidecarContainer();
    public ContainerTemplate buildTlsSidecarContainer();
    public A withTlsSidecarContainer(ContainerTemplate tlsSidecarContainer);
    public Boolean hasTlsSidecarContainer();
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> withNewTlsSidecarContainer();
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> withNewTlsSidecarContainerLike(ContainerTemplate item);
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> editTlsSidecarContainer();
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> editOrNewTlsSidecarContainer();
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> editOrNewTlsSidecarContainerLike(ContainerTemplate item);

    public interface StatefulsetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<ZookeeperClusterTemplateFluent.StatefulsetNested<N>>{

        
    public N and();    public N endStatefulset();
}
    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<ZookeeperClusterTemplateFluent.PodNested<N>>{

        
    public N and();    public N endPod();
}
    public interface ClientServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<ZookeeperClusterTemplateFluent.ClientServiceNested<N>>{

        
    public N and();    public N endClientService();
}
    public interface NodesServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<ZookeeperClusterTemplateFluent.NodesServiceNested<N>>{

        
    public N and();    public N endNodesService();
}
    public interface PersistentVolumeClaimNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<N>>{

        
    public N and();    public N endPersistentVolumeClaim();
}
    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<N>>{

        
    public N and();    public N endPodDisruptionBudget();
}
    public interface ZookeeperContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<ZookeeperClusterTemplateFluent.ZookeeperContainerNested<N>>{

        
    public N and();    public N endZookeeperContainer();
}
    public interface TlsSidecarContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<N>>{

        
    public N and();    public N endTlsSidecarContainer();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/template/ZookeeperClusterTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface ZookeeperClusterTemplateFluent<A extends ZookeeperClusterTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildStatefulset instead.
 * @return The buildable object.
 */
@Deprecated public StatefulSetTemplate getStatefulset();
    public StatefulSetTemplate buildStatefulset();
    public A withStatefulset(StatefulSetTemplate statefulset);
    public Boolean hasStatefulset();
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> withNewStatefulset();
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> withNewStatefulsetLike(StatefulSetTemplate item);
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> editStatefulset();
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> editOrNewStatefulset();
    public ZookeeperClusterTemplateFluent.StatefulsetNested<A> editOrNewStatefulsetLike(StatefulSetTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public ZookeeperClusterTemplateFluent.PodNested<A> withNewPod();
    public ZookeeperClusterTemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public ZookeeperClusterTemplateFluent.PodNested<A> editPod();
    public ZookeeperClusterTemplateFluent.PodNested<A> editOrNewPod();
    public ZookeeperClusterTemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildClientService instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getClientService();
    public ResourceTemplate buildClientService();
    public A withClientService(ResourceTemplate clientService);
    public Boolean hasClientService();
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> withNewClientService();
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> withNewClientServiceLike(ResourceTemplate item);
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> editClientService();
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> editOrNewClientService();
    public ZookeeperClusterTemplateFluent.ClientServiceNested<A> editOrNewClientServiceLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildNodesService instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getNodesService();
    public ResourceTemplate buildNodesService();
    public A withNodesService(ResourceTemplate nodesService);
    public Boolean hasNodesService();
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> withNewNodesService();
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> withNewNodesServiceLike(ResourceTemplate item);
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> editNodesService();
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> editOrNewNodesService();
    public ZookeeperClusterTemplateFluent.NodesServiceNested<A> editOrNewNodesServiceLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPersistentVolumeClaim instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getPersistentVolumeClaim();
    public ResourceTemplate buildPersistentVolumeClaim();
    public A withPersistentVolumeClaim(ResourceTemplate persistentVolumeClaim);
    public Boolean hasPersistentVolumeClaim();
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> withNewPersistentVolumeClaim();
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> withNewPersistentVolumeClaimLike(ResourceTemplate item);
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> editPersistentVolumeClaim();
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> editOrNewPersistentVolumeClaim();
    public ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<A> editOrNewPersistentVolumeClaimLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildZookeeperContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getZookeeperContainer();
    public ContainerTemplate buildZookeeperContainer();
    public A withZookeeperContainer(ContainerTemplate zookeeperContainer);
    public Boolean hasZookeeperContainer();
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> withNewZookeeperContainer();
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> withNewZookeeperContainerLike(ContainerTemplate item);
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> editZookeeperContainer();
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> editOrNewZookeeperContainer();
    public ZookeeperClusterTemplateFluent.ZookeeperContainerNested<A> editOrNewZookeeperContainerLike(ContainerTemplate item);
    
/**
 * This method has been deprecated, please use method buildTlsSidecarContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getTlsSidecarContainer();
    public ContainerTemplate buildTlsSidecarContainer();
    public A withTlsSidecarContainer(ContainerTemplate tlsSidecarContainer);
    public Boolean hasTlsSidecarContainer();
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> withNewTlsSidecarContainer();
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> withNewTlsSidecarContainerLike(ContainerTemplate item);
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> editTlsSidecarContainer();
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> editOrNewTlsSidecarContainer();
    public ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<A> editOrNewTlsSidecarContainerLike(ContainerTemplate item);

    public interface StatefulsetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StatefulSetTemplateFluent<ZookeeperClusterTemplateFluent.StatefulsetNested<N>>{

        
    public N and();    public N endStatefulset();
}
    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<ZookeeperClusterTemplateFluent.PodNested<N>>{

        
    public N and();    public N endPod();
}
    public interface ClientServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<ZookeeperClusterTemplateFluent.ClientServiceNested<N>>{

        
    public N and();    public N endClientService();
}
    public interface NodesServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<ZookeeperClusterTemplateFluent.NodesServiceNested<N>>{

        
    public N and();    public N endNodesService();
}
    public interface PersistentVolumeClaimNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<ZookeeperClusterTemplateFluent.PersistentVolumeClaimNested<N>>{

        
    public N and();    public N endPersistentVolumeClaim();
}
    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<ZookeeperClusterTemplateFluent.PodDisruptionBudgetNested<N>>{

        
    public N and();    public N endPodDisruptionBudget();
}
    public interface ZookeeperContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<ZookeeperClusterTemplateFluent.ZookeeperContainerNested<N>>{

        
    public N and();    public N endZookeeperContainer();
}
    public interface TlsSidecarContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<ZookeeperClusterTemplateFluent.TlsSidecarContainerNested<N>>{

        
    public N and();    public N endTlsSidecarContainer();
}


}
